An data.frame or tibble representing the day of year for the last frost, or NA if no frost occurs
Arguments
.data
A data frame or tibble containing daily minimum temperatures in a column named "mint".
threshold
The stress temperature threshold for frost (default: 0)
hemisphere
Hemisphere indicator: "south" or "north" (default: "south").
If latitude information is available in the data, it will be used to determine the hemisphere.
require_full_year
Logical. If TRUE, requires exactly 365 or 366 days (default: TRUE)