powered by
An options manager for configuring tidyweather parameters. This object provides methods to get and set weather-related parameters.
weather_options
An object of class list of length 3.
list
Frost threshold for extreme weather events. Default: 0
Whether to require a full year of data for certain calculations. Default: TRUE
Retrieve the value of an option by its key (e.g., "extreme.frost_threshold")
Set the value of an option by its key
Reset all options to their default values
# Get default frost threshold weather_options$get("extreme.frost_threshold") # Set custom values weather_options$set("extreme.frost_threshold" = -2) # Reset to defaults weather_options$reset()
Run the code above in your browser using DataLab